BOOST_PP_TUPLE_REMOVE_D

The BOOST_PP_TUPLE_REMOVE_D macro removes an element from a tuple. It reenters BOOST_PP_WHILE with maximum efficiency.

#### Usage

BOOST_PP_TUPLE_REMOVE_D(d, tuple, i) (v)

#### Arguments

d
  The next available BOOST_PP_WHILE iteration.
tuple
  The tuple from which an element is to be removed.
i
  The zero-based position in tuple of the element to be removed. Valid values range from 0 to BOOST_PP_TUPLE_SIZE(tuple) - 1. If tuple has only a single element, it remains unchanged since a tuple must have at least one element.

#### See Also

- BOOST_PP_TUPLE_REMOVE

#### Requirements

Header: <boost/preprocessor/tuple/remove.hpp>

© Copyright Edward Diener 2013

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)